================================
community.kubevirt Release Notes
================================

.. contents:: Topics


v1.0.0
======

Release Summary
---------------

This is the first stable release version of community.kubevirt.

v0.1.0
======

Release Summary
---------------

This is the first pre-release version of community.kubevirt after migrating from community.general.

Bugfixes
--------

- kubevirt - Add aliases 'interface_name' for network_name (https://github.com/ansible/ansible/issues/55641).
